@@ -61,7 +61,44 @@ if (IS_SKYSQL(hostname)) \
 { \
   diag("Not supported by SkySQL"); \
   return SKIP; \
-}       
+}
+
+#ifndef HAVE_SSL
+#define SKIP_NOTLS \
+{ \
+  diag("TLS not supported"); \
+  return SKIP;\
+}
+#else
+#define SKIP_NOTLS
+#endif
+
+#define SKIP_TLS \
+if (force_tls)\
+{\
+  diag("Test doesn't work with TLS");\
+  return SKIP;\
+}
+
+MYSQL *mysql_default = NULL;  /* default connection */
+
+#define IS_MAXSCALE()\
+   ((mysql_default && strstr(mysql_get_server_info(mysql_default), "maxScale")) ||\
+    (getenv("srv")!=NULL && (strcmp(getenv("srv"), "maxscale") == 0 ||\
+     strcmp(getenv("srv"), "skysql-ha") == 0)))
+#define SKIP_MAXSCALE \
+if (IS_MAXSCALE()) \
+{ \
+  diag("test disabled with maxscale"); \
+  return SKIP; \
+}
+
+#define SKIP_LOAD_INFILE_DISABLE \
+if (!((mysql->server_capabilities & CLIENT_LOCAL_FILES) &&  \
+         (mysql->options.client_flag & CLIENT_LOCAL_FILES))) { \
+  diag("Load local infile not supported"); \
+  return SKIP; \
+}
 
 #define MAX_KEY MAX_INDEXES
 #define MAX_KEY_LENGTH_DECIMAL_WIDTH 4          /* strlen("4096") */
@@ -115,7 +152,7 @@ do {\
 do {\
   if (expr)\
   {\
-    diag("Error: %s (%s: %d)", (reason) ? reason : "", __FILE__, __LINE__);\
+    diag("Error: %s (%s: %d)", reason, __FILE__, __LINE__);\
     return FAIL;\
   }\
 } while(0)
@@ -173,6 +210,7 @@ static const char *schema = 0;
 static char *hostname = 0;
 static char *password = 0;
 static unsigned int port = 0;
+static unsigned int ssl_port = 0;
 static char *socketname = 0;
 static char *username = 0;
 static int force_tls= 0;
@@ -413,6 +451,7 @@ void get_options(int argc, char **argv)
       break;
     case 'P':
       port= atoi(optarg);
+      ssl_port=port;
       break;
     case 'S':
       socketname= optarg;
@@ -469,6 +508,8 @@ MYSQL *test_connect(struct my_tests_st *test)
   }
   mysql_options(mysql, MYSQL_REPORT_DATA_TRUNCATION, &truncation_report);
   mysql_options(mysql, MYSQL_OPT_CONNECT_TIMEOUT, &timeout);
+  if (plugindir)
+    mysql_options(mysql, MYSQL_PLUGIN_DIR, plugindir);
 
   /* option handling */
   if (test && test->options) {
@@ -508,7 +549,7 @@ MYSQL *test_connect(struct my_tests_st *test)
 static int reset_connection(MYSQL *mysql) {
   int rc;
 
-  if (is_mariadb)
+  if (is_mariadb && !IS_MAXSCALE())
     rc= mysql_change_user(mysql, username, password, schema);
   else
     rc= mysql_reset_connection(mysql);
@@ -527,7 +568,14 @@ static int reset_connection(MYSQL *mysql) {
 void get_envvars() {
   char  *envvar;
 
-  if (getenv("MYSQL_TEST_TRAVIS"))
+  if (!getenv("MYSQLTEST_VARDIR") &&
+      !getenv("MARIADB_CC_TEST"))
+  {
+    skip_all("Tests skipped.\nFor running unittest suite outside of MariaDB server tests,\nplease specify MARIADB_CC_TEST environment variable.");
+    exit(0);
+  }
+
+  if (getenv("TRAVIS_JOB_ID"))
     travis_test= 1;
 
   if (!hostname && (envvar= getenv("MYSQL_TEST_HOST")))
@@ -555,6 +603,15 @@ void get_envvars() {
       port= atoi(envvar);
     diag("port: %d", port);
   }
+  if (!ssl_port)
+  {
+    if ((envvar= getenv("MYSQL_TEST_SSL_PORT")))
+      ssl_port= atoi(envvar);
+    else
+      ssl_port = port;
+    diag("ssl_port: %d", ssl_port);
+  }
+
   if (!force_tls && (envvar= getenv("MYSQL_TEST_TLS")))
     force_tls= atoi(envvar);
   if (!socketname)
@@ -599,12 +656,39 @@ MYSQL *my_test_connect(MYSQL *mysql,
 
 void run_tests(struct my_tests_st *test) {
   int i, rc, total=0;
-  MYSQL *mysql, *mysql_default= NULL;  /* default connection */
+  MYSQL *mysql;
 
   while (test[total].function)
     total++;
   plan(total);
 
+  /* display TLS stats */
+  mysql= mysql_init(NULL);
+  mysql_ssl_set(mysql, NULL, NULL, NULL, NULL, NULL);
+
+  if (!mysql_real_connect(mysql, hostname, username, password, schema, port, socketname, 0))
+  {
+    BAIL_OUT("Can't establish TLS connection to server.");
+  }
+
+  if (!mysql_query(mysql, "SHOW VARIABLES LIKE '%ssl%'"))
+  {
+    MYSQL_RES *res;
+    MYSQL_ROW row;
+
+    diag("TLS server variables");
+    diag("--------------------");
+
+    res= mysql_store_result(mysql);
+    while ((row= mysql_fetch_row(res)))
+      diag("%s: %s", row[0], row[1]);
+    mysql_free_result(res);
+    diag("Cipher in use: %s", mysql_get_ssl_cipher(mysql));
+    diag("--------------------");
+  }
+  mysql_close(mysql);
+
+
   if ((mysql_default= test_connect(NULL)))
   {
     diag("Testing against MySQL Server %s", mysql_get_server_info(mysql_default));
